@@ -17,7 +17,7 @@
 )]
 //! A simple database system that allows the use of multiple different backends.
 
-use serde::{Deserialize, Serialize};
+use serde::{de::DeserializeOwned, Serialize};
 use std::fmt::Debug;
 
 pub mod backend;
@@ -28,9 +28,9 @@ pub mod gateway;
 /// A marker trait for use within the [`Database`].
 ///
 /// This signifies that the type can be stored within a [`Database`].
-pub trait Settings {}
+pub trait Settings: Serialize + DeserializeOwned + Debug {}
 
-impl<T> Settings for T where T: Serialize + for<'de> Deserialize<'de> + Debug {}
+impl<T> Settings for T where T: Serialize + DeserializeOwned + Debug {}
 
 pub use self::database::Database;
 #[doc(inline)]
